(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('rxjs/operators'), require('rxjs')) :
    typeof define === 'function' && define.amd ? define(['exports', 'rxjs/operators', 'rxjs'], factory) :
    (global = global || self, factory(global.RxjsNumber = {}, global.rxjs.operators, global.rxjs));
}(this, (function (exports, operators, rxjs) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */

    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    }

    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }

    /**
     * @packageDocumentation
     * @module Number
     */
    /**
     * @private
     * @internal
     * @param input
     */

    function createOrReturnObservable(input) {
      return rxjs.isObservable(input) ? input : rxjs.of(input);
    }

    /**
     * Returns an Observable that emits a number that is the addition of the source number with input number
     *
     * @category Math
     *
     * @param num The number to add to the source value
     *
     * @example Returns a number that is the addition of source and input
     * ```ts
     * const input = [2, 3, 4, 5, 6];
     * from(input).pipe(add(3)).subscribe();
     * ```
     * Output: `5, 6, 7, 8, 9`
     *
     * @returns Observable that emits a number that is the addition of source and input
     */

    function add(num) {
      var num$ = createOrReturnObservable(num);
      return function (source) {
        return source.pipe(operators.withLatestFrom(num$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              numValue = _b[1];

          return value + numValue;
        }));
      };
    }

    /**
     * Returns an Observable that emits a number value rounded to the number of digits passed
     *
     * @category Math
     *
     * @param precision Maximum number of digits to round the number to
     *
     * @example Return a number to fixed position of `2`
     * ```ts
     * const input = [1.8372, 2.12353, 3.14, 42.2];
     * from(input).pipe(roundTo(2)).subscribe();
     * ```
     * Output: `1.84, 2.12, 3.14, 42.2`
     *
     * @returns Observable that emits a number number to a fixed decimal value
     */

    function roundTo(precision) {
      var precision$ = createOrReturnObservable(precision);
      return function (source) {
        return source.pipe(operators.withLatestFrom(precision$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              precisionValue = _b[1];

          var factor = Math.pow(10, precisionValue);
          return Math.round(value * factor) / factor;
        }));
      };
    }

    /**
     * Returns an Observable that emits the calculated mean number value from an Iterable of numbers
     *
     * @category Distribution
     *
     * @param precision Precision to round the result to, default is `3`
     *
     * @example
     * Return the mean of the source number arrays
     * ```ts
     * const source$ = from([ [1, 2, 3], [10, 15, 8], [5, 10, 100] ]);
     *
     * source$.pipe(mean()).subscribe();
     * ```
     * Output: `2, 11, 38.333`
     *
     * @returns Observable that emits a number that is the mean of all values in the source Iterable
     */

    function mean(precision) {
      if (precision === void 0) {
        precision = 3;
      }

      return function (source) {
        return source.pipe(operators.map(function (_a) {
          var _b = __read(_a),
              value = _b.slice(0);

          return [value.length, value.reduce(function (a, b) {
            return a += b;
          })];
        }), operators.map(function (_a) {
          var _b = __read(_a, 2),
              length = _b[0],
              value = _b[1];

          return value / length;
        }), roundTo(precision));
      };
    }

    /**
     * @private
     * @internal
     */

    var ERROR_MESSAGE = "div operator cannot divide by 0";
    /**
     * Returns an Observable that emits a number that is the division of the source number with input number
     *
     * @category Math
     *
     * @param num The number to divide to the source value
     *
     * @remarks If the input value is `0` this operator will throw an error
     *
     * @example Returns a number that is the division of source and input
     * ```ts
     * const input = [4, 10, 12, 18, 20];
     * from(input).pipe(div(2)).subscribe();
     * ```
     * Output: `2, 5, 6, 9, 10`
     *
     * @returns Observable that emits a number that is the division of source and input
     */

    function div(num) {
      var num$ = createOrReturnObservable(num);
      return function (source) {
        return source.pipe(operators.withLatestFrom(num$), operators.switchMap(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              numValue = _b[1];

          return numValue !== 0 ? rxjs.of(value / numValue) : rxjs.throwError(ERROR_MESSAGE);
        }));
      };
    }

    /**
     * Returns an Observable that emits numbers, where that number falls between the provided `min` and `max` values.
     *
     * @remarks When filtering in range, the range numbers are included in the filter - to exclude them set
     *   `excludeBoundingValues = true`
     *
     * @category Filter
     *
     * @see The [[inRange]] operator returns a boolean value instead of the number
     * @see The [[filterOutOfRange]] can be used to get numbers that fall outside the `min` and `max` range
     *
     * @param min The minimum range value
     * @param max The maximum range value
     * @param excludeBounds Also filter the `min` and `max` values from the Observable
     *
     * @example
     * Return only numbers in and including the range of `0` to `10`
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(filterInRange(0, 10)).subscribe();
     * ```
     * Output: `0, 1, 2, 3.4, 4.2, 10`
     *
     * @example
     * Return only numbers in the range of `0` to `10` and also filter the `min` and `max`
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(filterInRange(0, 10, true)).subscribe();
     * ```
     * Output: `1, 2, 3.14, 4.2`
     *
     * @returns Observable that emits a number that falls within the passed `min` and `max` range
     */

    function filterInRange(min, max, excludeBounds) {
      var min$ = createOrReturnObservable(min);
      var max$ = createOrReturnObservable(max);
      var excludeBounds$ = createOrReturnObservable(excludeBounds);
      return function (source) {
        return source.pipe(operators.withLatestFrom(min$, max$, excludeBounds$), operators.filter(function (_a) {
          var _b = __read(_a, 4),
              value = _b[0],
              minValue = _b[1],
              maxValue = _b[2],
              excludeBoundsValue = _b[3];

          return excludeBoundsValue ? value > minValue && value < maxValue : value >= minValue && value <= maxValue;
        }), operators.map(function (_a) {
          var _b = __read(_a, 1),
              value = _b[0];

          return value;
        }));
      };
    }

    /**
     * Returns an Observable that emits numbers from a source where they pass the check of Number.isFinite.
     *
     * @category Filter
     *
     * @remarks Certain operations such as dividing by zero or multiplying passed `Number.MAX_VALUE` in JavaScript can cause
     *   Infinity to be generated, this operator can help avoid those values
     *
     * @see The [[isFinite]] operator returns a boolean value instead of the number
     *
     * @example
     * Return only finite values
     * ```ts
     * const input = [-Infinity, -2.3, 0, 1, Infinity, 3.14, 4.2, 10, 11, Number.MAX_VALUE * 2];
     * from(input).pipe(filterIsFinite()).subscribe();
     * ```
     * Output: `-2.3, 0, 2, 3.14, 4.2, 10, 11`
     *
     * @returns Observable that emits numbers that are finite
     */

    function filterIsFinite() {
      return function (source) {
        return source.pipe(operators.filter(function (value) {
          return Number.isFinite(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits only valid finite floating point numbers from a source
     *
     * @category Filter
     *
     * @see The [[isFloat]] operator returns a boolean value instead of the number
     *
     * @example
     * Return only values that are floating point numbers
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(filterIsFloat()).subscribe();
     * ```
     * Output: `-2.3, 3.14, 4.2`
     *
     * @returns Observable that emits valid finite floating point numbers
     */

    function filterIsFloat() {
      return function (source) {
        return source.pipe(operators.filter(function (value) {
          return !Number.isNaN(value) && Number.isFinite(value) && !Number.isInteger(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits only integer numbers from a source that pass the check of Number.isInteger.
     *
     * @category Filter
     *
     * @see The [[isInteger]] operator returns a boolean value instead of the number
     *
     * @example
     * Return only values that are integer values
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(filterIsInteger()).subscribe()
     * ```
     * Output: `-10, 0, 1, 2, 10, 11, 42`
     *
     * @returns Observable that emits integer numbers
     */

    function filterIsInteger() {
      return function (source) {
        return source.pipe(operators.filter(function (value) {
          return Number.isInteger(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits number values from a source filtering out any NaN values.
     *
     * @category Filter
     *
     * @see The [[isNaN]] and [[isNotNaN]] operator returns a boolean value instead of the number
     *
     * @example
     * Returns only valid numbers where the source may contain NaN values
     * ```ts
     * const input = [NaN, -2.3, 0, NaN, 2, 3.14, 4.2, NaN, 11, 42];
     * from(input).pipe(filterNaN()).subscribe()
     * ```
     * Output: `-2.3, 0, 2, 3.14, 4.2, 11, 42`
     *
     * @returns Observable that emits valid numbers and excludes NaN values
     */

    function filterNaN() {
      return function (source) {
        return source.pipe(operators.filter(function (value) {
          return !Number.isNaN(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits numbers that are within the safe number range for JavaScript number precision using
     * Number.isSafeInteger
     *
     * @category Filter
     *
     * @see The [[isSafeInteger]] operator returns a boolean value instead of the number
     *
     * @example
     * Returns only integers within safe precision range
     * ```ts
     * // `Math.pow(2, 53)` is not within the safe integer range
     * const input = [-10, -2.3, 0, 1, 2, 3.14, Math.pow(2, 53) - 1, Math.pow(2, 53), Infinity];
     * from(input).pipe(filterIsSafeInteger()).subscribe()
     * ```
     * Output: `-10, 0, 1, 2, 9007199254740991`
     *
     * @returns Observable that emits integer numbers within `Number.isSafeInteger` equality check
     */

    function filterIsSafeInteger() {
      return function (source) {
        return source.pipe(operators.filter(function (num) {
          return Number.isSafeInteger(num);
        }));
      };
    }

    /**
     * Returns an Observable that emits numbers, where that number falls outside the provided `min` and `max` values.
     *
     * @remarks When filtering out-of-range, the range numbers are excluded from the filter - to include them set
     *   `includeBounds = true`
     *
     * @category Filter
     *
     * @see The [[inRange]] operator returns a boolean value instead of the number
     * @see The [[filterOutOfRange]] can be used to get numbers that fall outside the `min` and `max` range
     *
     * @param min The minimum range value
     * @param max The maximum range value
     * @param includeBounds Optionally include the `min` and `max` values in the Observable
     *
     * @example
     * Returns values outside the `min` and `max` range
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(filterOutOfRange(0, 10)).subscribe();
     * ```
     * Output: `-10, -2.3, 11, 42`
     *
     * @example
     * Returns values outside and including the `min` and `max` range
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(filterOutOfRange(0, 10, true)).subscribe();
     * ```
     * Output: `-10, -2.3, 0, 10, 11, 42`
     *
     * @returns Observable that emits a number that falls outside the `min` and `max` ranges
     */

    function filterOutOfRange(min, max, includeBounds) {
      var min$ = createOrReturnObservable(min);
      var max$ = createOrReturnObservable(max);
      var includeBounds$ = createOrReturnObservable(includeBounds);
      return function (source) {
        return source.pipe(operators.withLatestFrom(min$, max$, includeBounds$), operators.filter(function (_a) {
          var _b = __read(_a, 4),
              value = _b[0],
              minvalue = _b[1],
              maxValue = _b[2],
              includeBoundsValue = _b[3];

          return includeBoundsValue ? value <= minvalue || value >= maxValue : value < minvalue || value > maxValue;
        }), operators.map(function (_a) {
          var _b = __read(_a, 1),
              value = _b[0];

          return value;
        }));
      };
    }

    /**
     * @packageDocumentation
     * @module Number
     */

    /**
     * Get the fibonacci number
     * @private
     * @internal
     * @param n
     * @param memo
     */
    function fibonacci(n, memo) {
      return memo[n] || (n <= 2 ? 1 : memo[n] = fibonacci(n - 1, memo) + fibonacci(n - 2, memo));
    }

    /**
     * @packageDocumentation
     * @module Number
     */
    /**
     * Returns an Observable that emits a sequence of numbers in the
     * {@link https://en.wikipedia.org/wiki/Fibonacci_number|Fibonacci} sequence, starting from `0`
     *
     * @category Create
     *
     * @param iterations The number of iterations to do, must be greater than `0`
     * @param emitDelay If set the observable will emit per millisecond set, by default this is 0
     *
     * @example
     * Emit the first 5 numbers of the Fibonacci sequence immediately
     * ```ts
     * fromFibonacci(5).subscribe();
     * ```
     * Output: `0, 1, 1, 2, 3`
     *
     * @example
     * Emit the first 10 numbers of the Fibonacci sequence once per second, and skip `0`
     * ```ts
     * fromFibonacci(10, 1000).pipe(skip(1)).subscribe();
     * ```
     * Output: `1, 1, 2, 3, 5, 8, 13, 21, 34`
     *
     * @returns Observable of a Fibonacci sequence of numbers starting from `0`
     */

    function fromFibonacci(iterations, emitDelay) {
      if (emitDelay === void 0) {
        emitDelay = 0;
      }

      return new rxjs.Observable(function (subscriber) {
        var memo = {};

        if (iterations <= 0) {
          subscriber.error("fromFibonacci must be passed a positive integer value");
          return subscriber.complete();
        }

        var sub = rxjs.timer(0, emitDelay).pipe(operators.takeWhile(function (value) {
          return value < iterations;
        }), operators.map(function (value) {
          return value === 0 ? 0 : fibonacci(value, memo);
        }), operators.tap(function (value) {
          return subscriber.next(value);
        }), operators.finalize(function () {
          return !subscriber.closed && subscriber.complete();
        })).subscribe();
        subscriber.add(sub);
      });
    }

    /**
     * @packageDocumentation
     * @module Number
     */

    /**
     * Returns if the input is an array or
     * @private
     * @internal
     * @param input
     */
    function isArrayOrSet(input) {
      if (Array.isArray(input)) {
        return true;
      } else return input instanceof Set;
    }

    /**
     * Returns an Observable that emits numbers as a type-safe number generator from a source, if no source is passed it
     * will generate an infinite sequence of positive numbers starting from 0
     *
     * @category Create
     *
     * @param input Optional number source to emit from
     *
     * @example
     * Return an Observable that emits numbers from an Array and multiply by `2`
     * ```ts
     * fromNumber([1, 2, 3, 4]).pipe(mul(2)).subscribe();
     * ```
     * Output: `2, 4, 6, 8`
     *
     * @example
     * Returns an Observable of numbers and take the first 1000, and reduce to an array
     * ```ts
     * fromNumber().pipe(take(1000), reduce((acc, val) => [...acc, val], [])).subscribe();
     * ```
     * Output: `[0, 1, 2, 3, 4, ...]`
     *
     * @returns Observable that emits numbers passed from arguments or array
     */

    function fromNumber(input) {
      return new rxjs.Observable(function (subscriber) {
        if (input) {
          var sub = createOrReturnObservable(input).pipe(operators.takeWhile(function () {
            return !subscriber.closed;
          }), operators.map(function (value) {
            return isArrayOrSet(value) ? __spread(value) : [value];
          }), operators.tap(function (value) {
            for (var i = 0; i < value.length; i++) {
              subscriber.next(value[i]);
            }
          }), operators.finalize(function () {
            /* istanbul ignore next-line */
            !subscriber.closed && subscriber.complete();
          })).subscribe();
          subscriber.add(sub);
        } else {
          var sub = rxjs.timer(0, 0).pipe(operators.tap(function (value) {
            return subscriber.next(value);
          }), operators.finalize(function () {
            /* istanbul ignore next-line */
            !subscriber.closed && subscriber.complete();
          })).subscribe();
          subscriber.add(sub);
        }
        /* istanbul ignore next-line */


        return function () {
          return !subscriber.closed && subscriber.complete();
        };
      });
    }

    /**
     * Returns an Observable that emits booleans about values from a source that fall within the passed `min` and `max`
     * range, including the range numbers.
     *
     * @remarks When querying in range, the range numbers are included in the query - to exclude them set
     *   `excludeBoundingValues = true`
     *
     * @category Query
     *
     * @see The [[filterInRange]] operator returns the number value
     *
     * @param min The minimum number for the range
     * @param max The maximum number for the range
     * @param excludeBounds Optionally filter the `min` and `max` values from the Observable
     *
     * @example
     * Returns a boolean value if the number is in the range
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(inRange(0, 10)).subscribe();
     * ```
     * Output: `false, false, true, true, true, true, true, true, false, false`
     *
     * @example
     * Returns a boolean value if the number is in the range excluding the `min` and `max`
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(inRange(0, 10, true)).subscribe();
     * ```
     * Output: `false, false, false, true, true, true, true, false, false, false`
     *
     * @returns Observable that emits a boolean if the source number falls within the passed `min` and `max` range
     */

    function inRange(min, max, excludeBounds) {
      var min$ = createOrReturnObservable(min);
      var max$ = createOrReturnObservable(max);
      var excludeBounds$ = createOrReturnObservable(excludeBounds);
      return function (source) {
        return source.pipe(operators.withLatestFrom(min$, max$, excludeBounds$), operators.map(function (_a) {
          var _b = __read(_a, 4),
              value = _b[0],
              minValue = _b[1],
              maxValue = _b[2],
              excludeBoundsValue = _b[3];

          return excludeBoundsValue ? value > minValue && value < maxValue : value >= minValue && value <= maxValue;
        }));
      };
    }

    /**
     * Returns an Observable that emits a boolean value when a source number is a finite number using Number.isFinite
     *
     * @category Query
     *
     * @see The [[filterIsFinite]] operator returns the number value
     *
     * @example
     * Return boolean for finite values
     * ```ts
     * const input = [-Infinity, -2.3, 0, 1, Infinity, 3.14, 4.2, 10, 11, Number.MAX_VALUE * 2];
     * from(input).pipe(isFinite()).subscribe();
     * ```
     * Output: `false, true, true, true, false, true, true, true, true, false`
     *
     * @returns Observable that emits a boolean of a source number being finite
     */

    function isFinite() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return Number.isFinite(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits a boolean value when a source number is a a valid finite floating point number
     *
     * @category Query
     *
     * @see The [[filterIsFloat]] operator returns the number value
     *
     * @example
     * Return boolean for floating point numbers
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(isFloat()).subscribe();
     * ```
     * Output: `false, true, false, false, false, true, true, false, false, false`
     *
     * @returns Observable that emits a boolean of a source number is a valid finite floating point
     */

    function isFloat() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return !Number.isNaN(value) && Number.isFinite(value) && !Number.isInteger(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits a boolean value when a source number is an integer checked with Number.isInteger
     *
     * @category Query
     *
     * @see The [[filterIsInteger]] operator returns the number value
     *
     * @example
     * Return booleans for values that are integer values
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(isInteger()).subscribe()
     * ```
     * Output: `true, false, true, true, true, false, false, true, true, true`
     *
     * @returns Observable that emits a boolean of a source number being an integer
     */

    function isInteger() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return Number.isInteger(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits a boolean is the source number has no remainder from the passed modulus
     *
     * @category Query
     *
     * @param modulus The dividing number for the Modulo operation
     *
     * @example Return if the source value has no remainder for modulus `3`
     * ```ts
     * const input = [2, 3, 4, 5, 6];
     * from(input).pipe(isMod(3)).subscribe();
     * ```
     * Output: `false, true, false, false, true`
     *
     * @returns Observable that emits a boolean is the source number has no remainder
     */

    function isMod(modulus) {
      var modulus$ = createOrReturnObservable(modulus);
      return function (source) {
        return source.pipe(operators.withLatestFrom(modulus$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              modulusValue = _b[1];

          return value % modulusValue === 0;
        }));
      };
    }

    /**
     * Returns an Observable that emits a boolean value when a source number is a NaN value from Number.isNaN.
     *
     * @category Query
     *
     * @see The [[filterNaN]] operator returns numbers excluding NaN values
     *
     * @example
     * Return a boolean if a number is a NaN value
     * ```ts
     * const input = ['Ninja', 1, 2, NaN, 3.14, undefined];
     * from(input).pipe(isNaN()).subscribe();
     * ```
     * Output: `true, false, false, true, false, true`
     *
     * @returns Observable that emits a boolean value of a number being valid or NaN
     */

    function isNaN() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return Number.isNaN(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits a boolean value when a source number is valid and not NaN, checked using
     * Number.isNaN
     *
     * @category Query
     *
     * @remarks This is mostly for convenience of getting truthy values that are valid for numbers without flipping the
     *   value os `isNaN`
     *
     * @see The [[filterNaN]] operator returns numbers excluding NaN values
     *
     * @example
     * Return a boolean if a number is not NaN value
     * ```ts
     * const input = ['Ninja', 1, 2, NaN, 3.14, undefined];
     * from(input).pipe(isNotNaN()).subscribe();
     * ```
     * Output: `false, true, true, false, true, false`
     *
     * @returns Observable that emits a boolean value of a number being valid or NaN
     */

    function isNotNaN() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return !Number.isNaN(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits a boolean value when a source number has precision safety using Number.isSafeInteger
     *
     * @category Query
     *
     * @see The [[filterIsSafeInteger]] operator returns the number value
     *
     * @example
     * Return a boolean if a number does not have percision safety
     * ```ts
     * // `Math.pow(2, 53)` is not within the safe integer range
     * const input = [-10, -2.3, 0, 1, 2, 3.14, Math.pow(2, 53) - 1, Math.pow(2, 53), Infinity];
     * from(input).pipe(isSafeInteger()).subscribe()
     * ```
     * Output: `true, false, true, true, true, false, true, false, false`
     *
     * @returns Observable that emits a boolean value of a number has precision safety
     */

    function isSafeInteger() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return Number.isSafeInteger(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits the maximum number value from an Iterable of numbers
     *
     * @category Distribution
     *
     * @example
     * Return the max of the source number Array
     * ```ts
     * const source$ = from([ [1, 2, 3], [10, 15, 8], [5, 10, 100] ]);
     *
     * source$.pipe(max()).subscribe();
     * ```
     * Output: `3, 15, 100`
     *
     * @returns Observable that emits a number that is the maximum value in the source Iterable
     */

    function max() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return __spread(value).reduce(function (a, b) {
            return Math.max(a, b);
          });
        }));
      };
    }

    /**
     * Returns an Observable that emits the median number value from an Iterable of numbers
     *
     * @category Distribution
     *
     * @example
     * Return the median of the source number Array
     * ```ts
     * const source$ = from([ [1, 2, 3], [10, 15, 8], [5, 10, 100] ]);
     *
     * source$.pipe(median()).subscribe();
     * ```
     * Output: `2, 15, 52.5`
     *
     * @returns Observable that emits a number that is the median value in the source Iterable
     */

    function median(precision) {
      if (precision === void 0) {
        precision = 3;
      }

      return function (source) {
        return source.pipe(operators.map(function (_a) {
          var _b = __read(_a),
              value = _b.slice(0);

          return [value.sort(), Math.ceil(value.length / 2)];
        }), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              mid = _b[1];

          return value.length % 2 === 0 ? (value[mid] + value[mid - 1]) / 2 : value[mid - 1];
        }), roundTo(precision));
      };
    }

    /**
     * Returns an Observable that emits the minimum number value from an Iterable of numbers
     *
     * @category Distribution
     *
     * @example
     * Return the min of the source number Array
     * ```ts
     * const source$ = from([ [1, 2, 3], [10, 15, 8], [5, 10, 100] ]);
     *
     * source$.pipe(min()).subscribe();
     * ```
     * Output: `1, 8, 5`
     *
     * @returns Observable that emits a number that is the minimum value in the source Iterable
     */

    function min() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return __spread(value).reduce(function (a, b) {
            return Math.min(a, b);
          });
        }));
      };
    }

    /**
     * Returns an Observable that emits a number that is the remainder of the Modulo operation of the source number
     * by the divider
     *
     * @category Math
     *
     * @param modulus The dividing number for the Modulo operation
     *
     * @example Return the remainder of modulus `3`
     * ```ts
     * const input = [2, 3, 4, 5, 6];
     * from(input).pipe(mod(3)).subscribe();
     * ```
     * Output: `2, 0, 1, 2, 0`
     *
     * @returns Observable that emits a number that is reminder of a Modulo operation
     */

    function mod(modulus) {
      var modulus$ = createOrReturnObservable(modulus);
      return function (source) {
        return source.pipe(operators.withLatestFrom(modulus$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              modulusValue = _b[1];

          return value % modulusValue;
        }));
      };
    }

    /**
     * Returns an Observable that emits a number that is the multiplication of the source number with input number
     *
     * @category Math
     *
     * @param num The number to multiply to the source value
     *
     * @example Returns a number that is the multiplication of source and input
     * ```ts
     * const input = [2, 3, 4, 5, 6];
     * from(input).pipe(mul(2)).subscribe();
     * ```
     * Output: `4, 6, 8, 10, 12`
     *
     * @returns Observable that emits a number that is the multiplication of source and input
     */

    function mul(num) {
      var num$ = createOrReturnObservable(num);
      return function (source) {
        return source.pipe(operators.withLatestFrom(num$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              numValue = _b[1];

          return value * numValue;
        }));
      };
    }

    /**
     * Returns an Observable that emits booleans about values from a source that fall outside the passed `min` and `max`
     * range, excluding the range numbers.
     *
     * @remarks When querying out-of-range, the range numbers are querying from the filter - to include them set
     *   `includeBounds = true`
     *
     * @category Query
     *
     * @see To get numbers outside of a range use [[filterOutOfRange]]
     *
     * @param min The minimum number for the range
     * @param max The maximum number for the range
     * @param includeBounds Optionally include the `min` and `max` values in the Observable
     *
     * @example Returns a boolean value if the number is out the range including the `min` and `max`
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(outOfRange(0, 10)).subscribe();
     * ```
     * Output: `true, true, true, false, false, false, false, true, true, true`
     *
     * @example Returns a boolean value if the number is out the range excluding the `min` and `max`
     * ```ts
     * const input = [-10, -2.3, 0, 1, 2, 3.14, 4.2, 10, 11, 42];
     * from(input).pipe(outOfRange(0, 10, true)).subscribe();
     * ```
     * Output: `true, true, false, false, false, false, false, false, true, true`
     *
     * @returns Observable that emits a boolean if the source number falls outside the passed `min` and `max` range

     */

    function outOfRange(min, max, includeBounds) {
      var min$ = createOrReturnObservable(min);
      var max$ = createOrReturnObservable(max);
      var includeBounds$ = createOrReturnObservable(includeBounds);
      return function (source) {
        return source.pipe(operators.withLatestFrom(min$, max$, includeBounds$), operators.map(function (_a) {
          var _b = __read(_a, 4),
              value = _b[0],
              minValue = _b[1],
              maxValue = _b[2],
              includeBoundsValue = _b[3];

          return includeBoundsValue ? value <= minValue || value >= maxValue : value < minValue || value > maxValue;
        }));
      };
    }

    /**
     * Returns an Observable that emits a number from a source string using Number.parseFloat.
     *
     * @category Parse
     *
     * @example Return only parsed number values using base `10`
     * ```ts
     * const input = ['RxJS', '-2.3', '0', '1', '2', '3.14', 'Infinity'];
     * from(input).pipe(parseFloat()).subscribe();
     * ```
     * Output: `-2.3, 0, 1, 2, 3.14`
     *
     * @returns Observable that emits a number from source parsed string
     */

    function parseFloat() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return Number.parseFloat(value);
        }));
      };
    }

    /**
     * Returns an Observable that emits a number from a source hex using Number.parseInt.
     *
     * @category Parse
     *
     * @example Return only parsed hex values
     * ```ts
     * const input = ['RxJS', 'ff', '00', '1b', '23', 'c89bb'];
     * from(input).pipe(parseHex()).subscribe();
     * ```
     * Output: `255, 0, 27, 25, 821691`
     *
     * @returns Observable that emits a number from source hex value
     */

    function parseHex() {
      return function (source) {
        return source.pipe(operators.map(function (value) {
          return Number.parseInt(value, 16);
        }));
      };
    }

    /**
     * Returns an Observable that emits a number from a source string using Number.parseInt.
     *
     * @category Parse
     *
     * @param radix The number base to convert from. Default is base `10`
     *
     * @example Return only parsed integer values using base `10`
     * ```ts
     * const input = ['RxJS', '-2.3', '0', '1', '2', '3.14', 'Infinity'];
     * from(input).pipe(parseInt()).subscribe();
     * ```
     * Output: `-2, 0, 1, 2, 3`
     *
     * @example Return parsed integer values using base `16`
     * ```ts
     * const input = ['1', 'ff', '40'];
     * from(input).pipe(parseInt(16)).subscribe();
     * ```
     * Output: `1, 255, 64`
     *
     * @returns Observable that emits a number from source parsed string, optionally returns NaN values
     */

    function parseInt(radix) {
      if (radix === void 0) {
        radix = 10;
      }

      var radix$ = createOrReturnObservable(radix);
      return function (source) {
        return source.pipe(operators.withLatestFrom(radix$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              inputValue = _b[1];

          return Number.parseInt(value, inputValue);
        }));
      };
    }

    /**
     * Returns an Observable that emits a number from a source number that is raised by the passed power using the
     * exponentiation operator `**`
     *
     * @category Math
     *
     * @param power The number to raise the value by
     *
     * @example Return values raised to the power `2`
     * ```ts
     * const input = [2, 4, 10, 16, 256];
     * from(input).pipe(pow(2)).subscribe();
     * ```
     * Output: `4, 25, 100, 256, 655356`
     *
     * @returns Observable that emits a number that is the raised source value by the power
     */

    function pow(power) {
      var power$ = createOrReturnObservable(power);
      return function (source) {
        return source.pipe(operators.withLatestFrom(power$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              inputValue = _b[1];

          return Math.pow(value, inputValue);
        }));
      };
    }

    /**
     * Returns an Observable that emits a number that is the subtraction of the source number with input number
     *
     * @category Math
     *
     * @param num The number to subtract to the source value
     *
     * @example Returns a number that is the subtract of source and input
     * ```ts
     * const input = [2, 3, 4, 5, 6];
     * from(input).pipe(sub(3)).subscribe();
     * ```
     * Output: `-1, 0, 1, 2, 3`
     *
     * @returns Observable that emits a number that is the subtraction of source and input
     */

    function sub(num) {
      var input$ = createOrReturnObservable(num);
      return function (source) {
        return source.pipe(operators.withLatestFrom(input$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              inputValue = _b[1];

          return value - inputValue;
        }));
      };
    }

    /**
     * Returns an Observable that emits a formatted string of a number raised to an exponential power using
     * Number.toExponential
     *
     * @category Formatting
     *
     * @param exponential The exponential value to raise the number by
     *
     * @example Return a string passed numbers to the exponential of `2`
     * ```ts
     * const input = [-1, 0, 1, 2, 3.4];
     * from(input).pipe(toExponential(2)).subscribe();
     * ```
     * Output: `'-1.00e+0', '0.00e+0', '1.00e+0', '2.30e+0', '3.14e+0'`
     *
     * @returns Observable that emits a formatted string of the exponential number

     */

    function toExponential(exponential) {
      var exponential$ = createOrReturnObservable(exponential);
      return function (source) {
        return source.pipe(operators.withLatestFrom(exponential$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              inputValue = _b[1];

          return value.toExponential(inputValue);
        }));
      };
    }

    /**
     * Returns an Observable that emits a formatted string value from a source number using Number.toFixed
     *
     * @category Formatting
     *
     * @param digits Optional number of digits to fix to, if not passed treated as `0`
     *
     * @example Return a string of a number to fixed position of `2`
     * ```ts
     * const input = [1.8372, 2.12353, 3.14, 42.2];
     * from(input).pipe(toFixed(2)).subscribe();
     * ```
     * Output: `'1.834', '2.12', '3.14', '42.20'`
     *
     * @returns Observable that emits a formatted string from a source number to a fixed decimal value

     */

    function toFixed(digits) {
      var digits$ = createOrReturnObservable(digits);
      return function (source) {
        return source.pipe(operators.withLatestFrom(digits$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              inputValue = _b[1];

          return value.toFixed(inputValue);
        }));
      };
    }

    /**
     * Returns an Observable that emits a string that is the hex value of a source number
     *
     * @category Formatting
     *
     * @example Return a hex value of source number
     * ```ts
     * const input = [2, 16, 32, 75, 255];
     * from(input).pipe(toHex()).subscribe();
     * ```
     * Output: `'2', '10', '20', '4b', 'ff'`
     *
     * @returns Observable that emits the hex value of a source number
     */

    function toHex() {
      return function (source) {
        return source.pipe(operators.map(function (number) {
          return number.toString(16);
        }));
      };
    }

    /**
     * Returns an Observable that emits a formatted string value from a source number using Number.toLocaleString with
     * optional formatting options provided by Intl.NumberFormat
     *
     * @category Formatting
     *
     * @param locales The locale or locales that the number is being formatted for
     * @param format Formatting of the string based on
     *   [Intl.NumberFormat](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat)
     *
     * @example Return a string with Dutch number formatting
     * ```ts
     * of(1000000).pipe(toLocaleString('nl-NL')).subscribe();
     * ```
     * Output: `'1.000.000'`
     *
     * @example Return a string with UK English number formatting
     * ```ts
     * of(1000000).pipe(toLocaleString('en-GB')).subscribe();
     * ```
     * Output: `'1,000,000'`
     *
     * @example Return a string with UK English number formatting and Euro currency style
     * ```ts
     * of(1000000).pipe(toLocaleString('en-GB', { currency: 'EUR', style: 'currency' })).subscribe();
     * ```
     * Output: `'€1,000,000.00'`
     *
     * @returns Observable that emits a formatted string from a source number
     */

    function toLocaleString(locales, format) {
      var locales$ = createOrReturnObservable(locales);
      var format$ = createOrReturnObservable(format);
      return function (source) {
        return source.pipe(operators.withLatestFrom(locales$, format$), operators.map(function (_a) {
          var _b = __read(_a, 3),
              number = _b[0],
              localeValue = _b[1],
              formatValue = _b[2];

          return number.toLocaleString(localeValue, formatValue);
        }));
      };
    }

    /**
     * Returns an Observable that emits a formatted string value from a source number using Number.toPrecision.
     *
     * @category Formatting
     *
     * @param precision The number of decimal places to format the precision to.
     *
     * @example Return a string of numbers formatted to a precision of 4 places
     * ```ts
     * const input = [123.456, 0.004, 1.23e5];
     * from(input).pipe(toPrecision(4)).subscribe();
     * ```
     * Output: `'123.5', '0.004000', '1.230e+5'`
     *
     * @returns Observable that emits a formatted string from a source number
     */

    function toPrecision(precision) {
      var precision$ = createOrReturnObservable(precision);
      return function (source) {
        return source.pipe(operators.withLatestFrom(precision$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              precisionValue = _b[1];

          return value.toPrecision(precisionValue);
        }));
      };
    }

    /**
     * Returns an Observable that emits a formatted string value from a source number using Number.toString
     *
     * @category Formatting
     *
     * @param radix The base number to format to. Default is `10`.
     *
     * @example Return string values of numbers using base `10` conversion
     * ```ts
     * const input = [1, 2, 3.14, 42];
     * from(input).pipe(toString()).subscribe();
     * ```
     * Output: `'1', '2', '3.14', '42'`
     *
     * @example Return string values of numbers using base `16` conversion
     * ```ts
     * const input = [8, 16, 32, 64];
     * from(input).pipe(toString(16)).subscribe();
     * ```
     * Output: `'8', '10', '20', '40'`
     *
     * @returns Observable that emits a formatted string from a source number and passed `radix` value
     */

    function toString(radix) {
      if (radix === void 0) {
        radix = 10;
      }

      var radix$ = createOrReturnObservable(radix);
      return function (source) {
        return source.pipe(operators.withLatestFrom(radix$), operators.map(function (_a) {
          var _b = __read(_a, 2),
              value = _b[0],
              radixValue = _b[1];

          return value.toString(radixValue);
        }));
      };
    }

    exports.add = add;
    exports.average = mean;
    exports.div = div;
    exports.filterInRange = filterInRange;
    exports.filterIsFinite = filterIsFinite;
    exports.filterIsFloat = filterIsFloat;
    exports.filterIsInteger = filterIsInteger;
    exports.filterIsSafeInteger = filterIsSafeInteger;
    exports.filterNaN = filterNaN;
    exports.filterOutOfRange = filterOutOfRange;
    exports.fromFibonacci = fromFibonacci;
    exports.fromNumber = fromNumber;
    exports.inRange = inRange;
    exports.isFinite = isFinite;
    exports.isFloat = isFloat;
    exports.isInteger = isInteger;
    exports.isMod = isMod;
    exports.isNaN = isNaN;
    exports.isNotNaN = isNotNaN;
    exports.isSafeInteger = isSafeInteger;
    exports.max = max;
    exports.mean = mean;
    exports.median = median;
    exports.min = min;
    exports.mod = mod;
    exports.mul = mul;
    exports.outOfRange = outOfRange;
    exports.parseFloat = parseFloat;
    exports.parseHex = parseHex;
    exports.parseInt = parseInt;
    exports.pow = pow;
    exports.roundTo = roundTo;
    exports.sub = sub;
    exports.toExponential = toExponential;
    exports.toFixed = toFixed;
    exports.toHex = toHex;
    exports.toLocaleString = toLocaleString;
    exports.toPrecision = toPrecision;
    exports.toString = toString;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
